@@ -1,7 +1,7 @@
 from django.core.management.base import AppCommand
 from django.db import models
 
-from djangosphinx.manager import SphinxModelManager
+from djangosphinx.models import SphinxModelManager
 
 class Command(AppCommand):
     help = "Prints generic configuration for any models which use a standard SphinxSearch manager."
